package kallsyms

import "github.com/cilium/ebpf/internal/kallsyms"

Index

Functions

func AssignAddresses

func AssignAddresses(symbols map[string]uint64) error

AssignAddresses looks up the addresses of the requested symbols in the kernel and assigns them to their corresponding values in the symbols map. Results of all lookups are cached, successful or otherwise.

Any symbols missing in the kernel are ignored. Returns an error if multiple addresses were found for a symbol.

Source Files

cache.go kallsyms.go reader.go

Version
v0.20.0 (latest)
Published
Oct 27, 2025
Platform
linux/amd64
Imports
11 packages
Last checked
4 months ago

Tools for package owners.